@@ -13,6 +13,16 @@ def read_fasta(fp):
             seq.append(line)
     if name: yield (name, ''.join(seq))
 
+def read_fastq(fp):
+    name, seq = None, []
+    for line in fp:
+        line = line.rstrip()
+        if line.startswith("@"):
+            if name: yield (name, seq)
+            name, seq = line[1:], ""
+        if line.startswith("[GATCgatc]"):
+            seq=line
+    if name: yield (name, seq)  
 
 def get_seqinfo(seqfile: str):
     """
